@@ -200,7 +200,7 @@ vaws3D <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=TRUE
                      as.double(vwghts),
                      double(dv),#swjy
                      double(dv0),#thi
-                     PACKAGE="fmri",DUP=FALSE)[c("bi","thnew","hakt")]
+                     PACKAGE="fmri",DUP=TRUE)[c("bi","thnew","hakt")]
     gc()
     theta <- array(tobj$thnew,dy) 
     dim(tobj$bi) <- dy[-4]
@@ -228,7 +228,7 @@ vaws3D <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=TRUE
 		       as.double(vwghts),
 		       double(dv),#swjy
 		       double(dv0),#thi
-		       PACKAGE="fmri",DUP=FALSE)[c("bi","thnew")]
+		       PACKAGE="fmri",DUP=TRUE)[c("bi","thnew")]
       ptheta <- array(pobj$thnew,dy) 
       rm(pobj) 
       gc()
@@ -275,7 +275,7 @@ vaws3D <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=TRUE
                            as.integer(ddim[3]),
                            as.integer(ddim[4]),
                            var = double(n1*n2*n3),
-                           PACKAGE="fmri",DUP=FALSE)$var
+                           PACKAGE="fmri",DUP=TRUE)$var
   cat("fmri.smooth: smooth the residuals","\n")
   residuals <- .Fortran("ihaws2",as.double(residuals),
                      as.double(sigma2),
@@ -300,7 +300,7 @@ vaws3D <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=TRUE
                      as.double(vwghts),
                      double(ddim[4]),#swjy
                      double(dv0),#thi
-                     PACKAGE="fmri",DUP=FALSE)$resnew
+                     PACKAGE="fmri",DUP=TRUE)$resnew
   dim(residuals) <- c(ddim[4],n1,n2,n3)
   gc()
 #   get variances and correlations
@@ -316,7 +316,7 @@ vaws3D <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=TRUE
                      as.integer(lags[1]),
                      as.integer(lags[2]),
                      as.integer(lags[3]),
-                     PACKAGE="fmri",DUP=FALSE)$scorr
+                     PACKAGE="fmri",DUP=TRUE)$scorr
   dim(scorr) <- lags                     
   cat("fmri.smooth: final variance estimate","\n")
   vartheta <- .Fortran("ivar",as.double(residuals),
@@ -327,7 +327,7 @@ vaws3D <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=TRUE
                            as.integer(n3),
                            as.integer(ddim[4]),
                            var = double(n1*n2*n3),
-                           PACKAGE="fmri",DUP=FALSE)$var
+                           PACKAGE="fmri",DUP=TRUE)$var
   vred <- array(vartheta/vartheta0,c(n1,n2,n3))
   vartheta <- vred/sigma2  #  sigma2 contains inverse variances
   z <- list(theta=theta,ni=tobj$bi,var=vartheta,vred=vred,vred0=median(vred[mask]),y=y,
@@ -500,7 +500,7 @@ vaws3Dfull <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=
                      double(dv),#swjy
                      double(dv0),#thi
                      double(ddim[4]),#resi
-                     PACKAGE="fmri",DUP=FALSE)[c("bi","thnew","hakt","resnew")]
+                     PACKAGE="fmri",DUP=TRUE)[c("bi","thnew","hakt","resnew")]
     gc()
     theta <- array(tobj$thnew,dy) 
     dim(tobj$bi) <- ddim[1:3]
@@ -535,7 +535,7 @@ vaws3Dfull <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=
                         double(dv),#swjy
                         double(dv0),#thi
                         double(ddim[4]),#resi
-		        PACKAGE="fmri",DUP=FALSE)[c("bi","thnew","resnew")]
+		        PACKAGE="fmri",DUP=TRUE)[c("bi","thnew","resnew")]
       ptheta <- array(pobj$thnew,dy) 
       rm(pobj) 
       gc()
@@ -584,7 +584,7 @@ vaws3Dfull <- function(y,qlambda=NULL,lkern="Gaussian",skern="Plateau",weighted=
                      as.integer(lags[1]),
                      as.integer(lags[2]),
                      as.integer(lags[3]),
-                     PACKAGE="fmri",DUP=FALSE)$scorr
+                     PACKAGE="fmri",DUP=TRUE)$scorr
   dim(scorr) <- lags                     
   vartheta <- 1/tobj$bi
   vred <- vartheta*sigma2
@@ -653,6 +653,6 @@ smooth3D <- function(y,lkern="Gaussian",weighted=FALSE,sigma2=NULL,mask=NULL,hma
                      double(prod(dlw)),
                      as.double(wghts),
                      double(dv),#swjy
-                     PACKAGE="fmri",DUP=FALSE)$thnew
+                     PACKAGE="fmri",DUP=TRUE)$thnew
 array(ysmooth,dy)
 }
