@@ -242,7 +242,7 @@ fmri.lm <- function(data,z,actype="smooth",vtype="var",step=0.01,contrast=c(1),v
                                      as.integer(dy[2]),
                                      as.integer(dy[3]),
                                      as.integer(dy[4]),
-                                     PACKAGE="fmri",DUP=FALSE)$residuals
+                                     PACKAGE="fmri",DUP=TRUE)$residuals
       dim(residuals) <- c(dy[4],prod(dy[1:3]))
       residuals <- t(residuals)
       b <- rep(1/dy[4],length=dy[4])
@@ -284,7 +284,7 @@ fmri.lm <- function(data,z,actype="smooth",vtype="var",step=0.01,contrast=c(1),v
                      as.integer(lags[1]),
                      as.integer(lags[2]),
                      as.integer(lags[3]),
-                     PACKAGE="fmri",DUP=FALSE)$scorr
+                     PACKAGE="fmri",DUP=TRUE)$scorr
   dim(corr) <- lags                     
   scale <- NULL
   if(keep=="all"){
